ThermalPrinterFlutter class
API pública do plugin de impressão térmica.
- Implemented types
Constructors
- ThermalPrinterFlutter({NetworkPrinterRepository? networkRepository})
- Cria a fachada do plugin.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkBluetoothPermissions(
) → Future< bool> -
Verifica se as permissões de Bluetooth foram concedidas.
override
-
connect(
{required Printer printer}) → Future< bool> -
Conecta-se à
printer.override -
disconnect(
{required Printer printer}) → Future< void> -
Desconecta-se da
printer.override -
discoverNetworkPrinters(
{dynamic onProgress(String)?, bool requireConfirmation = false}) → Future< List< Printer> > - Descobre automaticamente impressoras de rede na rede local
-
dispose(
) → Future< void> -
Libera recursos retidos pelo plugin (conexões de rede em pool).
override
-
enableBluetooth(
) → Future< bool> -
Solicita a habilitação do Bluetooth no dispositivo.
override
-
getPlatformVersion(
) → Future< String?> -
Retorna a versão da plataforma host.
override
-
getPrinters(
{required PrinterType printerType}) → Future< List< Printer> > -
Lista as impressoras disponíveis para o
printerTypeinformado.override -
getPrinterStatus(
{required Printer printer}) → Future< PrinterStatus> -
override
-
isBluetoothEnabled(
) → Future< bool> -
Indica se o Bluetooth está habilitado no dispositivo.
override
-
isConnected(
{required Printer printer}) → Future< bool> -
Indica se a
printerestá conectada.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printBytes(
{required List< int> bytes, required Printer printer, int copies = 1}) → Future<void> -
Envia
bytes(ESC/POS) para aprinter.override -
screenShotWidget(
BuildContext context, {required Widget widget, double pixelRatio = 3.0, int width = 576, int threshold = 160, bool flipHorizontal = false, bool applyTextScaling = true, bool useBetterText = true, double textScaleFactor = 1.3, bool dither = true}) → Future< Image> -
Renderiza
widgete retorna a imagem monocromática pronta para impressão. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited