MethodChannelThermalPrinterFlutter class
An implementation of ThermalPrinterFlutterPlatform that uses method channels.
- Implemented types
Constructors
- MethodChannelThermalPrinterFlutter({BluetoothPrinterRepository? bluetoothRepository, UsbPrinterRepository? usbRepository, NetworkPrinterRepository? networkRepository})
- Cria a implementação baseada em MethodChannel.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onWebUsbConnectionChange
→ Stream<
void> -
Emite um evento sempre que um dispositivo USB é conectado ou desconectado
(apenas Web, via eventos
connect/disconnectdonavigator.usb).no setteroverride - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkBluetoothPermissions(
) → Future< bool> -
override
-
connect(
{required Printer printer}) → Future< bool> -
override
-
disconnect(
{required Printer printer}) → Future< void> -
override
-
dispose(
) → Future< void> -
Libera recursos retidos (ex.: conexões de rede em pool).
override
-
enableBluetooth(
) → Future< bool> -
override
-
getPlatformVersion(
) → Future< String?> -
override
-
getPrinters(
{required PrinterType printerType}) → Future< List< Printer> > -
override
-
getPrinterStatus(
{required Printer printer}) → Future< PrinterStatus> -
override
-
isBluetoothEnabled(
) → Future< bool> -
override
-
isConnected(
{required Printer printer}) → Future< bool> -
override
-
isWebBluetoothSupported(
) → Future< bool> -
Indica se o ambiente atual suporta impressão Bluetooth BLE via
Web Bluetooth.
override
-
isWebUsbSupported(
) → Future< bool> -
Indica se o ambiente atual suporta impressão USB via WebUSB.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
printBytes(
{required List< int> bytes, required Printer printer}) → Future<void> -
override
-
requestPrinter(
{required PrinterType printerType}) → Future< Printer?> -
Abre o seletor de dispositivos da plataforma para o usuário autorizar uma
impressora, retornando-a já pronta para uso.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited