ThermalPrinterFlutterPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • ThermalPrinterFlutterPlatform
Implementers

Constructors

ThermalPrinterFlutterPlatform()
Constructs a ThermalPrinterFlutterPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
onWebUsbConnectionChange Stream<void>
Emite um evento sempre que um dispositivo USB é conectado ou desconectado (apenas Web, via eventos connect/disconnect do navigator.usb).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkBluetoothPermissions() Future<bool>
connect({required Printer printer}) Future<bool>
disconnect({required Printer printer}) Future<void>
dispose() Future<void>
Libera recursos retidos (ex.: conexões de rede em pool).
enableBluetooth() Future<bool>
getPlatformVersion() Future<String?>
getPrinters({required PrinterType printerType}) Future<List<Printer>>
getPrinterStatus({required Printer printer}) Future<PrinterStatus>
isBluetoothEnabled() Future<bool>
isConnected({required Printer printer}) Future<bool>
isWebBluetoothSupported() Future<bool>
Indica se o ambiente atual suporta impressão Bluetooth BLE via Web Bluetooth.
isWebUsbSupported() Future<bool>
Indica se o ambiente atual suporta impressão USB via WebUSB.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printBytes({required List<int> bytes, required Printer printer}) Future<void>
requestPrinter({required PrinterType printerType}) Future<Printer?>
Abre o seletor de dispositivos da plataforma para o usuário autorizar uma impressora, retornando-a já pronta para uso.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ThermalPrinterFlutterPlatform
The default instance of ThermalPrinterFlutterPlatform to use.
getter/setter pair